import {
  select,csv,scaleLinear,extent,axisLeft,axisBottom
  ,format,scaleTime,line,curveBasis
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

//data handelling
const render = data =>{  
  //value access
  const xValue = d=>d.timestamp;
  const xAxisLabel = 'Time';
  const yValue = d=>d.temperature;
   const yAxisLabel = 'Temperature';
  
  const margin ={top:50, right:35, bottom:50, left:120};
  const innerwidth = width - margin.right -margin.left;
  const innerheight = height - margin.top - margin.bottom;
  
  const circleradius = 6;
  
  
  //data transformation
  const xScale = scaleTime()
  .domain(extent(data,xValue))
  .range([0,innerwidth]).nice();

  const yScale = scaleLinear()
  .domain(extent(data,yValue))
  .range([innerheight,0])
  .nice();
  
  
  //Margin
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  //draw axis
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerheight)
  	.tickPadding(10);
  
 
  const yAxis = axisLeft(yScale)
  		.tickSize(-innerwidth)
  		.tickPadding(10);;
  
 
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform',`translate(0,${innerheight})`)
  	
  xAxisG.selectAll('.domain')
  			.remove();
  
   const yAxisG =  g.append('g').call(yAxis);
  	
  yAxisG.selectAll('.domain')
  		.remove();
  
  //Axis lable
  xAxisG.append('text')
  			.attr('class','axis-label')
    		.attr('y',40)
  			.attr('x',innerwidth/2)
  			.text(xAxisLabel)
  			.attr('fill','black');
  
  yAxisG.append('text')
  			.attr('class','axis-label')
    		.attr('y',-43)
  			.attr('x',-innerheight/2)
  			.text(yAxisLabel)
  			.attr('fill','black')
  			.attr('transform',`rotate(-90)`)
  			.attr('text-anchor','middle');
 
  
  //draw path  
	const lineGen = line()
  	.x(d=>xScale(xValue(d)))
  	.y(d=>yScale(yValue(d)))
  	.curve(curveBasis);
  	
  
  g.append('path')
  	.attr('class','line-path')
  	.attr('d',lineGen(data));
  
  //add Chart title
  g.append('text')
    .attr('class','title')
  	.attr('y',-10)
  	.text('Auto-mpg weight-horsepower relationship')
  	;
  
  
};

//get data and pass to data handelling
csv('https://vizhub.com/PabloReyesBetanzo/datasets/temperature-in-san-francisco.csv')
  .then(data=>{
		data.forEach(d => {
  	d.temperature = +d.temperature;
    d.timestamp = new Date(d.timestamp);
  });
  render(data);
});

